==> realestate-supervise-common-1.0.0-20190527.033121-2-sources.jar: cn/gtmap/realestate/supervise/entity/TjBdcdy.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.math.BigDecimal;

/**
 * @author hqz
 * @version 1.0, 2017/4/10
 * @description 不动产单元表
 */
@Table(name = "tj_bdcdy")
public class TjBdcdy implements Serializable {
    @Id
    //不动产单元id
    private String bdcdyid;
    //不动产单元号
    private String bdcdyh;
    //不动产类型
    private String bdclx;
    //权利人名称
    private String qlrmc;
    //权利人证件号
    private String qlrzjh;
    //登记状态
    private String djzt;
    //限制状态
    private String xzzt;
    //坐落
    private String zl;
    //用途
    private String yt;
    //一级行政区代码
    private String yjxzq;
    //二级行政区代码
    private String ejxzq;
    //二级行政区代码
    private String qlzt;
    //新增字段：面积
    private BigDecimal mj;
    //土地性质
    private String tdxz;

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }

    public String getXzzt() {
        return xzzt;
    }

    public void setXzzt(String xzzt) {
        this.xzzt = xzzt;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getYjxzq() {
        return yjxzq;
    }

    public void setYjxzq(String yjxzq) {
        this.yjxzq = yjxzq;
    }

    public String getEjxzq() {
        return ejxzq;
    }

    public void setEjxzq(String ejxzq) {
        this.ejxzq = ejxzq;
    }

    public String getQlzt() {
        return qlzt;
    }

    public void setQlzt(String qlzt) {
        this.qlzt = qlzt;
    }

    public BigDecimal getMj() {
        return mj;
    }

    public void setMj(BigDecimal mj) {
        this.mj = mj;
    }

    public String getTdxz() {
        return tdxz;
    }

    public void setTdxz(String tdxz) {
        this.tdxz = tdxz;
    }
}

==> realestate-supervise-common-1.1.0-20251204.013828-71-sources.jar: cn/gtmap/realestate/supervise/entity/TjBdcdy.java <==
package cn.gtmap.realestate.supervise.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.math.BigDecimal;

/**
 * @author hqz
 * @version 1.0, 2017/4/10
 * @description 不动产单元表
 */
@Table(name = "tj_bdcdy")
public class TjBdcdy implements Serializable {
    @Id
    //不动产单元id
    private String bdcdyid;
    //不动产单元号
    private String bdcdyh;
    //不动产类型
    private String bdclx;
    //权利人名称
    private String qlrmc;
    //权利人证件号
    private String qlrzjh;
    //登记状态
    private String djzt;
    //限制状态
    private String xzzt;
    //坐落
    private String zl;
    //用途
    private String yt;
    //一级行政区代码
    private String yjxzq;
    //二级行政区代码
    private String ejxzq;
    //二级行政区代码
    private String qlzt;
    //新增字段：面积
    private BigDecimal mj;
    //土地性质
    private String tdxz;

    //业务人名称
    private  String ywrmc;

    //业务人证件号
    private  String ywrzjh;

    public String getYwrmc() {
        return ywrmc;
    }

    public void setYwrmc(String ywrmc) {
        this.ywrmc = ywrmc;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }

    public String getXzzt() {
        return xzzt;
    }

    public void setXzzt(String xzzt) {
        this.xzzt = xzzt;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getYjxzq() {
        return yjxzq;
    }

    public void setYjxzq(String yjxzq) {
        this.yjxzq = yjxzq;
    }

    public String getEjxzq() {
        return ejxzq;
    }

    public void setEjxzq(String ejxzq) {
        this.ejxzq = ejxzq;
    }

    public String getQlzt() {
        return qlzt;
    }

    public void setQlzt(String qlzt) {
        this.qlzt = qlzt;
    }

    public BigDecimal getMj() {
        return mj;
    }

    public void setMj(BigDecimal mj) {
        this.mj = mj;
    }

    public String getTdxz() {
        return tdxz;
    }

    public void setTdxz(String tdxz) {
        this.tdxz = tdxz;
    }
}
